from colorfield.fields import ColorField
from django.db import models
from django.utils.translation import gettext_lazy as _


class Asset(models.Model):
    title = models.CharField(_("title"), primary_key=True, max_length=200)
    picture = models.ImageField(_("picture"), upload_to="assets")

    def __str__(self):
        return self.title

    class Meta:
        verbose_name = _("asset")
        verbose_name_plural = _("assets")


class Parameter(models.Model):
    asset = models.ForeignKey(Asset, on_delete=models.CASCADE)
    name = models.CharField(_("name"), max_length=200)
    color = ColorField(verbose_name=_("color"))
    font_url = models.URLField(_("font url"))
    font_size = models.IntegerField(_("font size"), default=0)
    x = models.IntegerField(default=0)
    y = models.IntegerField(default=0)

    def __str__(self):
        return self.name

    class Meta:
        unique_together = (
            "asset",
            "name",
        )
        verbose_name = _("parameter")
        verbose_name_plural = _("parameters")



import os

from les_assets_generator.assets_generator.settings.base import *  # noqa: F401,F403

os.environ["DJANGO_SETTINGS_MODULE"] = "assets_generator.settings.dev"

# SECURITY WARNING: don't run with debug turned on in production!
DEBUG = True

# SECURITY WARNING: keep the secret key used in production secret!
SECRET_KEY = "e!m3b-!+@$=5t+=^vnw2l)7i6gi_fw^h=v(=0ojxfn^bx4z=!o"

# SECURITY WARNING: define the correct hosts in production!
ALLOWED_HOSTS = ["*"]

EMAIL_BACKEND = "django.core.mail.backends.console.EmailBackend"



from io import BytesIO
from urllib.request import urlopen

from django.http import HttpResponse
from django.shortcuts import get_object_or_404, redirect
from PIL import Image, ImageDraw, ImageFont

from les_assets_generator.app.models import Asset, Parameter


def index(request):
    return redirect("https://github.com/lyon-esport/assets-generator")


def generate(request, title: str):
    asset = get_object_or_404(Asset.objects.select_related(), pk=title)
    params = Parameter.objects.select_related().filter(asset=asset)

    img = Image.open(asset.picture)
    draw = ImageDraw.Draw(img)

    for param in params:
        param_value = request.GET.get(param.name)
        if param_value is None:
            return HttpResponse(f"Missing GET parameter {param}", status=422)

        try:
            font = ImageFont.truetype(urlopen(param.font_url), param.font_size)
        except OSError:
            return HttpResponse(f"Font {param.font_url} not supported", status=422)
        draw.text((param.x, param.y), param_value, font=font, fill=param.color)

    byte_io = BytesIO()
    img.save(byte_io, "png")
    byte_io.seek(0)

    return HttpResponse(byte_io, content_type="image/png")
